@@ -1,13 +1,13 @@
 package App::UpdateRinciMetadataDb;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Clean::JSON;
 use DBI;
@@ -35,6 +35,30 @@ sub _is_excluded {
     0;
 }
 
+our $db_schema_spec = {
+    latest_v => 2,
+    install => [
+        'CREATE TABLE IF NOT EXISTS package (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
+        'CREATE TABLE IF NOT EXISTS function (package VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(package, name))',
+    ],
+    upgrade_to_v2 => [
+        # rename to package
+        'DROP TABLE module',
+        'CREATE TABLE IF NOT EXISTS package (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
+
+        # we'll just drop everything and rebuild, since it's painful to
+        # rename column in sqlite
+        'DROP TABLE function',
+        'CREATE TABLE IF NOT EXISTS function (package VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(package, name))',
+    ],
+
+    # for testing
+    install_v1 => [
+        'CREATE TABLE IF NOT EXISTS module (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
+        'CREATE TABLE IF NOT EXISTS function (module VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(module, name))',
+    ],
+};
+
 $SPEC{update_rinci_metadata_db} = {
     v => 1.1,
     summary => 'Create/update Rinci API metadata database',
@@ -91,6 +115,7 @@ _
         },
         library => {
             summary => "Include library path, like Perl's -I",
+            schema => 'str*',
             description => <<'_',
 
 Note that some modules are already loaded before this option takes effect. To
@@ -168,28 +193,7 @@ sub update_rinci_metadata_db {
                            {RaiseError=>1});
 
     my $res = SQL::Schema::Versioned::create_or_update_db_schema(
-        spec => {
-            latest_v => 2,
-            # v1
-            #install => [
-            #    'CREATE TABLE IF NOT EXISTS module (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
-            #    'CREATE TABLE IF NOT EXISTS function (module VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(module, name))',
-            #],
-            install => [
-                'CREATE TABLE IF NOT EXISTS package (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
-                'CREATE TABLE IF NOT EXISTS function (package VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(package, name))',
-            ],
-            upgrade_to_v2 => [
-                # rename to package
-                'DROP TABLE module',
-                'CREATE TABLE IF NOT EXISTS package (name VARCHAR(255) PRIMARY KEY, summary TEXT, metadata BLOB, mtime INT)',
-
-                # we'll just drop everything and rebuild, since it's painful to
-                # rename column in sqlite
-                'DROP TABLE function',
-                'CREATE TABLE IF NOT EXISTS function (package VARCHAR(255) NOT NULL, name VARCHAR(255) NOT NULL, summary TEXT, metadata BLOB, UNIQUE(package, name))',
-            ],
-        },
+        spec => $db_schema_spec,
         dbh => $dbh,
     );
     return $res unless $res->[0] == 200;
@@ -312,7 +316,7 @@ App::UpdateRinciMetadataDb - Create/update Rinci API metadata database
 
 =head1 VERSION
 
-This document describes version 0.09 of App::UpdateRinciMetadataDb (from Perl distribution App-UpdateRinciMetadataDb), released on 2014-12-27.
+This document describes version 0.10 of App::UpdateRinciMetadataDb (from Perl distribution App-UpdateRinciMetadataDb), released on 2015-08-17.
 
 =head1 FUNCTIONS
 
@@ -338,7 +342,7 @@ DBI connection DSN.
 
 Note: has been tested with MySQL and SQLite only.
 
-=item * B<exclude> => I<array>
+=item * B<exclude> => I<array[str]>
 
 Perl package names or prefixes to exclude.
 
@@ -346,7 +350,7 @@ Perl package names or prefixes to exclude.
 
 Force update database even though module hasn't changed since last update.
 
-=item * B<library> => I<any>
+=item * B<library> => I<str>
 
 Include library path, like Perl's -I.
 
@@ -354,7 +358,7 @@ Note that some modules are already loaded before this option takes effect. To
 make sure you use the right library, you can use C<PERL5OPT> or explicitly use
 C<perl> and use its C<-I> option.
 
-=item * B<module_or_package>* => I<array>
+=item * B<module_or_package>* => I<array[str]>
 
 Perl module or prefixes or package to add/update.
 
@@ -383,11 +387,11 @@ C<list_subpackages>).
 
 DBI connection password.
 
-=item * B<require> => I<array>
+=item * B<require> => I<array[str]>
 
 Require a Perl module, a la Perl's -m.
 
-=item * B<use> => I<array>
+=item * B<use> => I<array[str]>
 
 Use a Perl module, a la Perl's -M.
 
@@ -407,8 +411,6 @@ Pass -dry_run=>1 to enable simulation mode.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -418,7 +420,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -442,7 +444,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
